@@ -15,7 +15,6 @@
 
 """Extension for hiding server addresses in certain states."""
 
-from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
 from nova.compute import vm_states
 import nova.conf
@@ -24,8 +23,6 @@ from nova.policies import hide_server_addresses as hsa_policies
 
 CONF = nova.conf.CONF
 
-ALIAS = 'os-hide-server-addresses'
-
 
 class Controller(wsgi.Controller):
     def __init__(self, *args, **kwargs):
@@ -52,9 +49,8 @@ class Controller(wsgi.Controller):
             return
 
         if 'server' in resp.obj and 'addresses' in resp.obj['server']:
-            resp_server = resp.obj['server']
-            instance = req.get_db_instance(resp_server['id'])
-            self._perhaps_hide_addresses(instance, resp_server)
+            instance = req.get_db_instance(id)
+            self._perhaps_hide_addresses(instance, resp.obj['server'])
 
     @wsgi.extends
     def detail(self, req, resp_obj):
@@ -67,17 +63,3 @@ class Controller(wsgi.Controller):
             if 'addresses' in server:
                 instance = req.get_db_instance(server['id'])
                 self._perhaps_hide_addresses(instance, server)
-
-
-class HideServerAddresses(extensions.V21APIExtensionBase):
-    """Support hiding server addresses in certain states."""
-
-    name = 'HideServerAddresses'
-    alias = ALIAS
-    version = 1
-
-    def get_controller_extensions(self):
-        return [extensions.ControllerExtension(self, 'servers', Controller())]
-
-    def get_resources(self):
-        return []
