@@ -10,11 +10,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_versionedobjects import base as ovo
+from sqlalchemy.orm import joinedload
 
+from nova import context
 from nova.db.sqlalchemy import api as db_api
 from nova.db.sqlalchemy import api_models
 from nova import exception
+from nova.i18n import _
 from nova.objects import base
 from nova.objects import cell_mapping
 from nova.objects import fields
@@ -26,10 +28,19 @@ def _cell_id_in_updates(updates):
         updates["cell_id"] = cell_mapping_obj.id
 
 
-# NOTE(danms): Maintain Dict compatibility because of ovo bug 1474952
+def _apply_updates(context, db_mapping, updates):
+    db_mapping.update(updates)
+    db_mapping.save(context.session)
+    # NOTE: This is done because a later access will trigger a lazy load
+    # outside of the db session so it will fail. We don't lazy load
+    # cell_mapping on the object later because we never need a HostMapping
+    # without the CellMapping.
+    db_mapping.cell_mapping
+    return db_mapping
+
+
 @base.NovaObjectRegistry.register
-class HostMapping(base.NovaTimestampObject, base.NovaObject,
-                  ovo.VersionedObjectDictCompat):
+class HostMapping(base.NovaTimestampObject, base.NovaObject):
     # Version 1.0: Initial version
     VERSION = '1.0'
 
@@ -63,7 +74,7 @@ class HostMapping(base.NovaTimestampObject, base.NovaObject,
             if key == "cell_mapping":
                 # NOTE(dheeraj): If cell_mapping is stashed in db object
                 # we load it here. Otherwise, lazy loading will happen
-                # when .cell_mapping is accessd later
+                # when .cell_mapping is accessed later
                 if not db_value:
                     continue
                 db_value = cell_mapping.CellMapping._from_db_object(
@@ -78,15 +89,11 @@ class HostMapping(base.NovaTimestampObject, base.NovaObject,
     @db_api.api_context_manager.reader
     def _get_by_host_from_db(context, host):
         db_mapping = (context.session.query(api_models.HostMapping)
-                      .join(api_models.CellMapping)
-                      .with_entities(api_models.HostMapping,
-                                     api_models.CellMapping)
+                      .options(joinedload('cell_mapping'))
                       .filter(api_models.HostMapping.host == host)).first()
         if not db_mapping:
             raise exception.HostMappingNotFound(name=host)
-        host_mapping = db_mapping[0]
-        host_mapping["cell_mapping"] = db_mapping[1]
-        return host_mapping
+        return db_mapping
 
     @base.remotable_classmethod
     def get_by_host(cls, context, host):
@@ -97,9 +104,7 @@ class HostMapping(base.NovaTimestampObject, base.NovaObject,
     @db_api.api_context_manager.writer
     def _create_in_db(context, updates):
         db_mapping = api_models.HostMapping()
-        db_mapping.update(updates)
-        db_mapping.save(context.session)
-        return db_mapping
+        return _apply_updates(context, db_mapping, updates)
 
     @base.remotable
     def create(self):
@@ -116,16 +121,14 @@ class HostMapping(base.NovaTimestampObject, base.NovaObject,
             id=obj.id).first()
         if not db_mapping:
             raise exception.HostMappingNotFound(name=obj.host)
-
-        db_mapping.update(updates)
-        return db_mapping
+        return _apply_updates(context, db_mapping, updates)
 
     @base.remotable
     def save(self):
         changes = self.obj_get_changes()
         # cell_mapping must be mapped to cell_id for updates
         _cell_id_in_updates(changes)
-        db_mapping = self._save_in_db(self._context, self.host, changes)
+        db_mapping = self._save_in_db(self._context, self, changes)
         self._from_db_object(self._context, self, db_mapping)
         self.obj_reset_changes()
 
@@ -140,3 +143,90 @@ class HostMapping(base.NovaTimestampObject, base.NovaObject,
     @base.remotable
     def destroy(self):
         self._destroy_in_db(self._context, self.host)
+
+
+@base.NovaObjectRegistry.register
+class HostMappingList(base.ObjectListBase, base.NovaObject):
+    # Version 1.0: Initial version
+    VERSION = '1.0'
+
+    fields = {
+        'objects': fields.ListOfObjectsField('HostMapping'),
+        }
+
+    @staticmethod
+    @db_api.api_context_manager.reader
+    def _get_by_cell_id_from_db(context, cell_id):
+        return (context.session.query(api_models.HostMapping)
+                .options(joinedload('cell_mapping'))
+                .filter(api_models.HostMapping.cell_id == cell_id)).all()
+
+    @base.remotable_classmethod
+    def get_by_cell_id(cls, context, cell_id):
+        db_mappings = cls._get_by_cell_id_from_db(context, cell_id)
+        return base.obj_make_list(context, cls(), HostMapping, db_mappings)
+
+
+def _check_and_create_host_mappings(ctxt, cm, compute_nodes, status_fn):
+    host_mappings = []
+    for compute in compute_nodes:
+        status_fn(_("Checking host mapping for compute host "
+                    "'%(host)s': %(uuid)s") %
+                  {'host': compute.host, 'uuid': compute.uuid})
+        try:
+            HostMapping.get_by_host(ctxt, compute.host)
+        except exception.HostMappingNotFound:
+            status_fn(_("Creating host mapping for compute host "
+                        "'%(host)s': %(uuid)s") %
+                      {'host': compute.host, 'uuid': compute.uuid})
+            host_mapping = HostMapping(
+                ctxt, host=compute.host,
+                cell_mapping=cm)
+            host_mapping.create()
+            host_mappings.append(host_mapping)
+            compute.mapped = 1
+            compute.save()
+    return host_mappings
+
+
+def discover_hosts(ctxt, cell_uuid=None, status_fn=None):
+    # TODO(alaski): If this is not run on a host configured to use the API
+    # database most of the lookups below will fail and may not provide a
+    # great error message. Add a check which will raise a useful error
+    # message about running this from an API host.
+
+    from nova import objects
+
+    if not status_fn:
+        status_fn = lambda x: None
+
+    if cell_uuid:
+        cell_mappings = [objects.CellMapping.get_by_uuid(ctxt, cell_uuid)]
+    else:
+        cell_mappings = objects.CellMappingList.get_all(ctxt)
+        status_fn(_('Found %s cell mappings.') % len(cell_mappings))
+
+    host_mappings = []
+    for cm in cell_mappings:
+        if cm.is_cell0():
+            status_fn(_('Skipping cell0 since it does not contain hosts.'))
+            continue
+        if 'name' in cm and cm.name:
+            status_fn(_("Getting compute nodes from cell '%(name)s': "
+                        "%(uuid)s") % {'name': cm.name,
+                                       'uuid': cm.uuid})
+        else:
+            status_fn(_("Getting compute nodes from cell: %(uuid)s") %
+                      {'uuid': cm.uuid})
+        with context.target_cell(ctxt, cm) as cctxt:
+            compute_nodes = objects.ComputeNodeList.get_all_by_not_mapped(
+                cctxt, 1)
+            status_fn(_('Found %(num)s unmapped computes in cell: %(uuid)s') %
+                      {'num': len(compute_nodes),
+                       'uuid': cm.uuid})
+            added_hm = _check_and_create_host_mappings(cctxt, cm,
+                                                       compute_nodes,
+                                                       status_fn)
+            host_mappings.extend(added_hm)
+
+    return host_mappings
