@@ -14,28 +14,14 @@
 #    under the License.
 
 import mock
-from oslo_config import cfg
 
+from nova import objects
 from nova.tests.functional.api_sample_tests import test_servers
 
-CONF = cfg.CONF
-CONF.import_opt('osapi_compute_extension',
-                'nova.api.openstack.compute.legacy_v2.extensions')
-
 
 class EvacuateJsonTest(test_servers.ServersSampleBase):
     ADMIN_API = True
-    extension_name = "os-evacuate"
-
-    def _get_flags(self):
-        f = super(EvacuateJsonTest, self)._get_flags()
-        f['osapi_compute_extension'] = CONF.osapi_compute_extension[:]
-        f['osapi_compute_extension'].append(
-            'nova.api.openstack.compute.contrib.evacuate.Evacuate')
-        f['osapi_compute_extension'].append(
-            'nova.api.openstack.compute.contrib.extended_evacuate_find_host.'
-            'Extended_evacuate_find_host')
-        return f
+    sample_dir = "os-evacuate"
 
     def _test_evacuate(self, req_subs, server_req, server_resp,
                        expected_resp_code):
@@ -76,7 +62,7 @@ class EvacuateJsonTest(test_servers.ServersSampleBase):
             # NOTE(gibi): no server_resp means we expect empty body as
             # a response
             self.assertEqual(expected_resp_code, response.status_code)
-            self.assertEqual('', response.content)
+            self.assertEqual('', response.text)
 
     @mock.patch('nova.conductor.manager.ComputeTaskManager.rebuild_instance')
     def test_server_evacuate(self, rebuild_mock):
@@ -146,3 +132,50 @@ class EvacuateJsonTestV214(EvacuateJsonTest):
                 orig_sys_metadata=mock.ANY, bdms=mock.ANY, recreate=mock.ANY,
                 on_shared_storage=None, preserve_ephemeral=mock.ANY,
                 host=None, request_spec=mock.ANY)
+
+
+class EvacuateJsonTestV229(EvacuateJsonTestV214):
+    microversion = '2.29'
+    scenarios = [('v2_29', {'api_major_version': 'v2.1'})]
+
+    @mock.patch('nova.conductor.manager.ComputeTaskManager.rebuild_instance')
+    @mock.patch('nova.objects.ComputeNodeList.get_all_by_host')
+    def test_server_evacuate(self, compute_node_get_all_by_host, rebuild_mock):
+        # Note (wingwj): The host can't be the same one
+        req_subs = {
+            'host': 'testHost',
+            "adminPass": "MySecretPass",
+            "force": "false",
+        }
+        fake_computes = objects.ComputeNodeList(
+            objects=[objects.ComputeNode(host='testHost',
+                                         hypervisor_hostname='host')])
+        compute_node_get_all_by_host.return_value = fake_computes
+        self._test_evacuate(req_subs, 'server-evacuate-req',
+                            server_resp=None, expected_resp_code=200)
+        rebuild_mock.assert_called_once_with(mock.ANY, instance=mock.ANY,
+                orig_image_ref=mock.ANY, image_ref=mock.ANY,
+                injected_files=mock.ANY, new_pass="MySecretPass",
+                orig_sys_metadata=mock.ANY, bdms=mock.ANY, recreate=mock.ANY,
+                on_shared_storage=None, preserve_ephemeral=mock.ANY,
+                host=None, request_spec=mock.ANY)
+
+    @mock.patch('nova.conductor.manager.ComputeTaskManager.rebuild_instance')
+    @mock.patch('nova.objects.ComputeNodeList.get_all_by_host')
+    def test_server_evacuate_with_force(self, compute_node_get_all_by_host,
+                                        rebuild_mock):
+        # Note (wingwj): The host can't be the same one
+        req_subs = {
+            'host': 'testHost',
+            "adminPass": "MySecretPass",
+            "force": "True",
+        }
+        self._test_evacuate(req_subs, 'server-evacuate-req',
+                            server_resp=None, expected_resp_code=200)
+        self.assertEqual(0, compute_node_get_all_by_host.call_count)
+        rebuild_mock.assert_called_once_with(mock.ANY, instance=mock.ANY,
+                orig_image_ref=mock.ANY, image_ref=mock.ANY,
+                injected_files=mock.ANY, new_pass="MySecretPass",
+                orig_sys_metadata=mock.ANY, bdms=mock.ANY, recreate=mock.ANY,
+                on_shared_storage=None, preserve_ephemeral=mock.ANY,
+                host='testHost', request_spec=mock.ANY)
