@@ -33,6 +33,7 @@ from oslo_utils import versionutils
 
 from nova.compute import power_state
 from nova.compute import task_states
+from nova.compute import vm_states
 import nova.conf
 from nova.console import type as ctype
 from nova import exception
@@ -513,8 +514,12 @@ class FakeDriver(driver.ComputeDriver):
         data.graphics_listen_addr_vnc = CONF.vnc.vncserver_listen
         data.graphics_listen_addr_spice = CONF.spice.server_listen
         data.serial_listen_addr = None
-        data.block_migration = block_migration
-        data.disk_over_commit = disk_over_commit or False  # called with None
+        # Notes(eliqiao): block_migration and disk_over_commit are not
+        # nullable, so just don't set them if they are None
+        if block_migration is not None:
+            data.block_migration = block_migration
+        if disk_over_commit is not None:
+            data.disk_over_commit = disk_over_commit
         data.disk_available_mb = 100000
         data.is_shared_block_storage = True
         data.is_shared_instance_path = True
@@ -535,7 +540,7 @@ class FakeDriver(driver.ComputeDriver):
 
     def pre_live_migration(self, context, instance, block_device_info,
                            network_info, disk_info, migrate_data):
-        return
+        return migrate_data
 
     def unfilter_instance(self, instance, network_info):
         return
@@ -608,3 +613,49 @@ class MediumFakeDriver(FakeDriver):
     vcpus = 10
     memory_mb = 8192
     local_gb = 1028
+
+
+class FakeRescheduleDriver(FakeDriver):
+    """FakeDriver derivative that triggers a reschedule on the first spawn
+    attempt. This is expected to only be used in tests that have more than
+    one compute service.
+    """
+    # dict, keyed by instance uuid, mapped to a boolean telling us if the
+    # instance has been rescheduled or not
+    rescheduled = {}
+
+    def spawn(self, context, instance, image_meta, injected_files,
+              admin_password, network_info=None, block_device_info=None):
+        if not self.rescheduled.get(instance.uuid, False):
+            # We only reschedule on the first time something hits spawn().
+            self.rescheduled[instance.uuid] = True
+            raise exception.ComputeResourcesUnavailable(
+                reason='FakeRescheduleDriver')
+        super(FakeRescheduleDriver, self).spawn(
+            context, instance, image_meta, injected_files,
+            admin_password, network_info, block_device_info)
+
+
+class FakeBuildAbortDriver(FakeDriver):
+    """FakeDriver derivative that always fails on spawn() with a
+    BuildAbortException so no reschedule is attempted.
+    """
+    def spawn(self, context, instance, image_meta, injected_files,
+              admin_password, network_info=None, block_device_info=None):
+        raise exception.BuildAbortException(
+            instance_uuid=instance.uuid, reason='FakeBuildAbortDriver')
+
+
+class FakeUnshelveSpawnFailDriver(FakeDriver):
+    """FakeDriver derivative that always fails on spawn() with a
+    VirtualInterfaceCreateException when unshelving an offloaded instance.
+    """
+    def spawn(self, context, instance, image_meta, injected_files,
+              admin_password, network_info=None, block_device_info=None):
+        if instance.vm_state == vm_states.SHELVED_OFFLOADED:
+            raise exception.VirtualInterfaceCreateException(
+                'FakeUnshelveSpawnFailDriver')
+        # Otherwise spawn normally during the initial build.
+        super(FakeUnshelveSpawnFailDriver, self).spawn(
+            context, instance, image_meta, injected_files,
+            admin_password, network_info, block_device_info)
